==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/en/messages.php <==
<?php

return [
    'Welcome to' => 'Welcome to :name Admin Dashboard.',
    'yes' => 'Yes',
    'no' => 'No',
    'list' => 'List',
    'show' => 'Show',
    'edit' => 'Edit',
    'action' => 'Action',
    'back' => 'Back',
    'save' => 'Save',
    'reset' => 'Reset',
    'cancel' => 'Cancel',
    'create' => 'Create',
    'new' => 'New',
    'created' => 'Created',
    'created_at' => 'Created at',
    'update' => 'Update',
    'updated' => 'Updated',
    'updated_at' => 'Updated At',
    'delete' => 'Delete',
    'deleted' => 'Deleted',
    'deleted at' => 'Deleted at',
    'deleted_list' => 'Deleted List',
    'trash' => 'Trash',
    'subject' => 'Subject',
    'unknown_user' => 'Unknown User',
    'Please fix the following errors & try again!' => 'Please fix the following errors & try again!',
    'Copyright' => 'Copyright',
    'change_language' => 'Change language',
    'Notifications' => 'Notifications',
    'you_have_:count_notifications' => 'You have :count notifications',
    ':count_unread' => ':count unread',
    'logout' => 'Logout',
    'are_you_sure?' => 'Are you sure you want to delete it?',
    'save_form' => ':form has been save successfully',
    'create_form' => ':form has been created successfully',
    'reset_form' => ':form permission has been reset successfully',
    'update_form' => ':form has been updated successfully',
    'delete_form' => ':form has been deleted successfully',
    'login_error' => 'You are not able to login please contact to admin',
    'user_logout' => 'User logged out successfully.',
    'register_successfull' => 'Register successfully',
    'not_matched' => 'The provided credentials do not match our records.',
    'user_notfound' => 'User not found',
    'same_pass' => 'Old and new password are same.',
    'pass_successfull' => 'Password successfully changed',
    'no_record' => 'No record found',
    'user_details_successfull' => 'User details retrieved successfully',
    'dashboard_detail' => 'Dashboard Detail',
    'gallery_notfound' => 'Gallery not found.',
    'user_list' => 'User List',
    'user_create' => 'User Created Sucessfully',
    'user_detail' => 'User Detail',
    'user_update' => 'User Updated Sucessfully',
    'user_delete' => 'User Deleted Sucessfully',
    'notification_list' => 'Notification Lists',
    'mark_read' => 'Mark as all read Notification Lists',
    'user_subscribe' => 'User Subscribe Successfully',
    'user_subscribe_history' => 'User Subscription Histroy',
    'subscribe_cancel' => 'Subscription plan cancelled',
    'profile_update' => 'Profile Updated',
    'bulk_update' => 'Bulk Action Updated',
    'bulk_status_update' => 'Bulk Branch Status Updated',
    'bulk_status_delete' => 'Bulk Branch Deleted',
    'bulk_booking_update' => 'Bulk Bookings Status Updated',
    'bulk_booking_delete' => 'Bulk Bookings Status Deleted',
    'bulk_category_update' => 'Bulk Category Status Updated',
    'bulk_category_delete' => 'Bulk Category Status Deleted',
    'bulk_customer_update' => 'Bulk Customer Status Updated',
    'bulk_customer_delete' => 'Bulk Customer Status Deleted',
    'bulk_employee_update' => 'Bulk Employee Status Updated',
    'bulk_employee_delete' => 'Bulk Employee Status Deleted',
    'password_update' => "Password Updated Successfully'",
    'google_blocked' => 'Customer have been Blocked',
    'google_unblocked' => 'Customer have been UnBlocked',
    'payment_done' => 'Payment has been completed',
    'password_update' => 'Password Updated Successfully',
    'employee_block' => 'Employee have been Blocked',
    'employee_unblock' => 'Employee have been Unblocked',
    'holiday_update' => 'Holiday Update successsfully',
    'bulk_notification_update' => 'Bulk Notification Status Updated',
    'bulk_notification_delete' => 'Bulk Notification Status Deleted',
    'bulk_notification_setting_update' => 'Notification Setting Updated Successfully',
    'bulk_package_update' => 'Bulk Package Status Updated',
    'bulk_package_delete' => 'Bulk Package Status Deleted',
    'bulk_service_update' => 'Bulk Service Status Updated',
    'bulk_service_delete' => 'Bulk Service Status Deleted',
    'bulk_slider_update' => 'Bulk Slider Status Updated',
    'bulk_slider_delete' => 'Bulk Slider Status Deleted',
    'bulk_plan_update' => 'Bulk Plan Status Updated',
    'bulk_plan_delete' => 'Bulk Plan Status Deleted',
    'bulk_planlimit_update' => 'Bulk PlanLimit Status Updated',
    'bulk_planlimit_delete' => 'Bulk PlanLimit Status Deleted',
    'bulk_tax_update' => 'Bulk Tax Status Updated',
    'bulk_tax_delete' => 'Bulk Tax Status Deleted',
    'custom_field' => 'Custom Field list',
    'currency_list' => 'Currency List',
    'customer_verify' => 'Customer Verified',
    'customer_field_list' => 'Custom Field list',
    'employee_verify' => 'Employee Verified',
    'notification_temp_list' => 'Notification Template list',
    'template' => 'Template',
    'service_staff_update' => 'Service Staff Updated Successfully',
    'service_branch_update' => 'Service Branch Updated Successfully',
    'service_gallery_update' => 'Service Gallery updated successfully',
    'user_login' => 'User login successfully.',
    'tips_data_store' => 'Data Restoreded Successfully !',
    'tips_data_delete' => 'Deleted Successfully',
    'tips_data_update' => 'Updated Successfully',
    'tips_data_add' => 'Data Added Successfully !',
    'currency_created' => 'Currencies Create Successfully',
    'currency_updated' => 'Currencies Update Successfully',
    'currency_deleted' => 'Currencies Deleted Successfully',
    'currency_data' => 'Data Restoreded Successfully !',
    'customfield_created' => 'CustomField Create Successfully',
    'customfield_updated' => 'CustomField Update Successfully',
    'customfield_deleted' => 'CustomField Deleted Successfully',
    'notification_updated' => 'Notification Update Successfully',
    'notification_deleted' => 'Notification Deleted Successfully',
    'plan_data' => 'Data Restoreded Successfully !',
    'language_data' => 'Data Restoreded Successfully !',
    'commission_data' => 'Data Restoreded Successfully !',
    'buissnesshour_data' => 'Data Restoreded Successfully !',
    'buissnesshour_deleted' => 'BuissnessHour Deleted Successfully',
    'buissnesshour_updated' => 'Notification Update Successfully',
    'buissnesshour_added' => 'BuissnessHour Create Successfully',
    'module_deleted' => 'Module Deleted Successfully',
    'module_updated' => 'Module Update Successfully',
    'module_added' => 'Module Create Successfully',
    'user_not_found' => 'User not found',
    'user' => 'user',
    'register_before_login' => 'Please register your account before login.',
    'permission_denied' => 'Permission denied you are in demo mode.',
    'unauthorised' => 'Unauthorised',
    'verification_link' => 'verification-link-sent',
    'setting_save' => 'Settings has been saved.',
    'appointment' => 'Appointment',
    'total_revenue' => 'Total Revenue',
    'sales_commission' => 'Sales Commissions',
    'new_customer' => 'New Customers',
    'view_all' => 'View All',
    'service' => 'Service',
    'total_count' => 'Total Count',
    'total_amount' => 'Total Amount',
    'top_service_notfound' => 'Not found top services',
    'no_action' => 'No Action',
    'status' => 'Status',
    'delete' => 'Delete',
    'active' => 'Active',
    'verify_email' => 'Verify Email',
    'inactive' => 'Inactive',
    'gallery_for_branch' => 'Gallery For Branch',
    'assign_staff_branch' => 'Assign Staff To Branch',
    'login_success' => 'Login Successfully.',
    'delete_account' => 'Your account has been scheduled for deletion.',
    'all_notifications' => 'All Notifications',
    'default_notification_body' => 'You have new notification',
    'notification_body' => 'Notification Message',
    'notification_link' => 'Notification Link',
    'you_unread_notification' => 'You have :number unread notifications',
    'mark_all_as_read' => 'Mark all as read',
    'no_notification' => 'No Notification Found',
    'cache_cleard' => 'Cache cleared ',
    'role_not_matched' => 'Role does not match the required role.',
    'select_status' => 'Select Status',
    'branches' => 'Branches',
    'service' => 'Service',
    'total_count' => 'Total Count',
    'total_amount' => 'Total Amount',
    'myprofile' => 'My Profile',
    'appointment' => 'Appointment',
    'calender_view' => 'Calendar View',
    'datatable_view' => 'Datatable View',
    'save_appointment' => 'Save Appointment',
    'data_not_available' => 'Data Not Available',
    'advance_filter' => 'Advance Filter',
    'gallery_for_service' => 'Gallery for Service',
    'password_mismatch' => 'New password and confirm password do not match.',
    'new_password_mismatch' => 'New password cannot be the same as the old password.',
    'old_password_mismatch' => 'Old Password Was Incorrect!',
    'bulk_logistic_update' => 'Bulk Logistic Status Updated',
    'bulk_logistic_delete' => 'Bulk LOgistic Status Deleted',
    'bulk_tag_update' => 'Bulk Tag Status Updated',
    'bulk_tag_delete' => 'Bulk Tag Status Deleted',
    'bulk_state_update' => 'Bulk State Status Updated',
    'bulk_state_delete' => 'Bulk State Status Deleted',
    'gallery_for_product' => 'Gallery for Product',
    'apply' => 'Apply',
    'export' => 'Export',
    'close' => 'Close',
    'all_status' => 'All Status',
    'all' => 'All ',
    'upload_images' => 'Upload Images ',
    'upload' => 'Upload',
    'remove' => 'Remove',
    'name' => 'Name',
    'search' => 'Search',
    'placeholder_phone' => 'Enter a Phone Number',
    'unisex' => 'Unisex',
    'male' => 'Male',
    'female' => 'Female',
    'intersex' => 'Intersex',
    'payment' => 'Payment',
    'order_code' => 'Order Code',
    'items' => 'Items',
    'placed_on' => 'Placed On',
    'type' => 'Type',
    'customer' => 'Customer',
    'currency' => 'Currency',
    'commission' => 'Commission',
    'confirm' => 'Confirm',
    'password_msg' => 'This is a secure area of the application. Please confirm your password before continuing.',
    'change_password' => 'Change Password',
    'save_changes' => 'Save Changes',
    'assign_staff' => 'Assign Staff',
    'logo' => 'Logo',
    'mini_logo' => 'Mini Logo',
    'dark_logo' => 'Dark Logo',
    'dark-mini_logo' => 'Dark Mini Logo',
    'favicon' => 'favicon',
    'select_staff' => 'Select Staff',
    'payout_to' => 'Payout To',
    'submit_date_filter' => 'Submit Date Filter',
    'total_product_revenue' => 'Data Filter Wise Total Product Revenue',
    'total_new_sales' => 'Data Filter Wise Total New Sales',
    'total_new_customers' => 'Data Filter Wise Total New Customers',
    'total_paid_commission' => 'Data Filter Wise Total Paid Commission',
    'total_revenue' => 'Data Filter Wise Total Revenue',
    'total_appointment_count' => 'Data Filter Wise Total of Appointments Count',
    'data_not_available' => 'Data is not available in this Table',
    'coupon_view' => 'View Coupon',
];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/en/messages.php <==
<?php

return [
    'Welcome to' => 'Welcome to :name Admin Dashboard.',
    'yes' => 'Yes',
    'no' => 'No',
    'list' => 'List',
    'show' => 'Show',
    'edit' => 'Edit',
    'action' => 'Action',
    'back' => 'Back',
    'save' => 'Save',
    'reset' => 'Reset',
    'cancel' => 'Cancel',
    'create' => 'Create',
    'new' => 'New',
    'created' => 'Created',
    'created_at' => 'Created at',
    'update' => 'Update',
    'updated' => 'Updated',
    'updated_at' => 'Updated At',
    'delete' => 'Delete',
    'deleted' => 'Deleted',
    'deleted at' => 'Deleted at',
    'deleted_list' => 'Deleted List',
    'trash' => 'Trash',
    'subject' => 'Subject',
    'unknown_user' => 'Unknown User',
    'Please fix the following errors & try again!' => 'Please fix the following errors & try again!',
    'Copyright' => 'Copyright',
    'change_language' => 'Change language',
    'Notifications' => 'Notifications',
    'you_have_:count_notifications' => 'You have :count notifications',
    ':count_unread' => ':count unread',
    'logout' => 'Logout',
    'are_you_sure?' => 'Are you sure you want to delete this  :name :module?',
    'save_form' => ':form has been save successfully',
    'create_form' => ':form has been created successfully',
    'reset_form' => ':form permission has been reset successfully',
    'update_form' => ':form has been updated successfully',
    'delete_form' => ':form has been deleted successfully',
    'login_error' => 'You are not able to login please contact to admin',
    'user_logout' => 'User logged out successfully.',
    'register_successfull' => 'Register successfully',
    'not_matched' => 'The provided credentials do not match our records.',
    'user_notfound' => 'User not found',
    'same_pass' => 'Old and new password are same.',
    'pass_successfull' => 'Password successfully changed',
    'no_record' => 'No record found',
    'user_details_successfull' => 'User details retrieved successfully',
    'dashboard_detail' => 'Dashboard Detail',
    'gallery_notfound' => 'Gallery not found.',
    'user_list' => 'User List',
    'user_create' => 'User Created Sucessfully',
    'user_detail' => 'User Detail',
    'user_update' => 'User Updated Sucessfully',
    'user_delete' => 'User Deleted Sucessfully',
    'notification_list' => 'Notification Lists',
    'mark_read' => 'Mark as all read Notification Lists',
    'user_subscribe' => 'User Subscribe Successfully',
    'user_subscribe_history' => 'User Subscription Histroy',
    'subscribe_cancel' => 'Subscription plan cancelled',
    'profile_update' => 'Profile Updated',
    'bulk_update' => 'Bulk Action Updated',
    'bulk_status_update' => 'Bulk Branch Status Updated',
    'bulk_status_delete' => 'Bulk Branch Deleted',
    'bulk_booking_update' => 'Bulk Bookings Status Updated',
    'bulk_booking_delete' => 'Bulk Bookings Status Deleted',
    'bulk_category_update' => 'Bulk Category Status Updated',
    'bulk_category_delete' => 'Bulk Category Status Deleted',
    'bulk_customer_update' => 'Bulk Customer Status Updated',
    'bulk_customer_delete' => 'Bulk Customer Status Deleted',
    'bulk_employee_update' => 'Bulk Employee Status Updated',
    'bulk_employee_delete' => 'Bulk Employee Status Deleted',
    'password_update' => "Password Updated Successfully'",
    'google_blocked' => 'Customer have been Blocked',
    'google_unblocked' => 'Customer have been UnBlocked',
    'payment_done' => 'Payment has been completed',
    'password_update' => 'Password Updated Successfully',
    'employee_block' => 'Employee have been Blocked',
    'employee_unblock' => 'Employee have been Unblocked',
    'holiday_update' => 'Holiday Update successsfully',
    'bulk_notification_update' => 'Bulk Notification Status Updated',
    'bulk_notification_delete' => 'Bulk Notification Status Deleted',
    'bulk_notification_setting_update' => 'Notification Setting Updated Successfully',
    'bulk_package_update' => 'Bulk Package Status Updated',
    'bulk_package_delete' => 'Bulk Package Status Deleted',
    'bulk_service_update' => 'Bulk Service Status Updated',
    'bulk_service_delete' => 'Bulk Service Status Deleted',
    'bulk_slider_update' => 'Bulk Slider Status Updated',
    'bulk_slider_delete' => 'Bulk Slider Status Deleted',
    'bulk_plan_update' => 'Bulk Plan Status Updated',
    'bulk_plan_delete' => 'Bulk Plan Status Deleted',
    'bulk_planlimit_update' => 'Bulk PlanLimit Status Updated',
    'bulk_planlimit_delete' => 'Bulk PlanLimit Status Deleted',
    'bulk_tax_update' => 'Bulk Tax Status Updated',
    'bulk_tax_delete' => 'Bulk Tax Status Deleted',
    'custom_field' => 'Custom Field list',
    'currency_list' => 'Currency List',
    'customer_verify' => 'Customer Verified',
    'customer_field_list' => 'Custom Field list',
    'employee_verify' => 'Employee Verified',
    'notification_temp_list' => 'Notification Template list',
    'template' => 'Template',
    'service_staff_update' => 'Service Staff Updated Successfully',
    'service_branch_update' => 'Service Branch Updated Successfully',
    'service_gallery_update' => 'Service Gallery updated successfully',
    'user_login' => 'User login successfully.',
    'tips_data_store' => 'Data Restoreded Successfully !',
    'tips_data_delete' => 'Deleted Successfully',
    'tips_data_update' => 'Updated Successfully',
    'tips_data_add' => 'Data Added Successfully !',
    'currency_created' => 'Currencies Create Successfully',
    'currency_updated' => 'Currencies Update Successfully',
    'currency_deleted' => 'Currencies Deleted Successfully',
    'currency_data' => 'Data Restoreded Successfully !',
    'customfield_created' => 'Custom Field Create Successfully',
    'customfield_updated' => 'Custom Field Update Successfully',
    'customfield_deleted' => 'Custom Field Deleted Successfully',
    'notification_updated' => 'Notification Update Successfully',
    'notification_deleted' => 'Notification Deleted Successfully',
    'plan_data' => 'Data Restoreded Successfully !',
    'language_data' => 'Data Restoreded Successfully !',
    'commission_data' => 'Data Restoreded Successfully !',
    'buissnesshour_data' => 'Data Restoreded Successfully !',
    'buissnesshour_deleted' => 'BuissnessHour Deleted Successfully',
    'buissnesshour_updated' => 'Notification Update Successfully',
    'buissnesshour_added' => 'Bussiness Hours Update Successfully',
    'module_deleted' => 'Module Deleted Successfully',
    'module_updated' => 'Module Update Successfully',
    'module_added' => 'Module Create Successfully',
    'user_not_found' => 'User not found',
    'user' => 'user',
    'register_before_login' => 'Please Enter Correct details or register.',
    'permission_denied' => 'Permission denied you are in demo mode.',
    'unauthorised' => 'Unauthorised',
    'verification_link' => 'verification-link-sent',
    'setting_save' => 'Settings has been saved.',
    'appointment' => 'Appointment',
    'total_revenue' => 'Total Revenue',
    'sales_commission' => 'Sales Commissions',
    'new_customer' => 'New Customers',
    'view_all' => 'View All',
    'service' => 'Service',
    'total_count' => 'Total Count',
    'total_amount' => 'Total Amount',
    'top_service_notfound' => 'Not found top services',
    'no_action' => 'No Action',
    'status' => 'Status',
    'delete' => 'Delete',
    'active' => 'Active',
    'verify_email' => 'Verify Email',
    'inactive' => 'Inactive',
    'gallery_for_branch' => 'Gallery For Branch',
    'assign_staff_branch' => 'Assign Staff To Branch',
    'login_success' => 'Login Successfully.',
    'delete_account' => 'Your account has been scheduled for deletion.',
    'all_notifications' => 'All Notifications',
    'default_notification_body' => 'You have new notification',
    'notification_body' => 'Notification Message',
    'notification_link' => 'Notification Link',
    'you_unread_notification' => 'You have :number unread notifications',
    'mark_all_as_read' => 'Mark all as read',
    'no_notification' => 'No Notification Found',
    'cache_cleard' => 'Cache cleared ',
    'role_not_matched' => 'Role does not match the required role.',
    'select_status' => 'Select Status',
    'branches' => 'Branches',
    'service' => 'Service',
    'total_count' => 'Total Count',
    'total_amount' => 'Total Amount',
    'myprofile' => 'My Profile',
    'appointment' => 'Appointment',
    'calender_view' => 'Calendar View',
    'datatable_view' => 'Datatable View',
    'save_appointment' => 'Save Appointment',
    'data_not_available' => 'Data Not Available',
    'advance_filter' => 'Advance Filter',
    'gallery_for_service' => 'Gallery for Service',
    'password_mismatch' => 'New password and confirm password do not match.',
    'new_password_mismatch' => 'New password cannot be the same as the old password.',
    'old_password_mismatch' => 'Old Password Was Incorrect!',
    'bulk_logistic_update' => 'Bulk Logistic Status Updated',
    'bulk_logistic_delete' => 'Bulk LOgistic Status Deleted',
    'bulk_tag_update' => 'Bulk Tag Status Updated',
    'bulk_tag_delete' => 'Bulk Tag Status Deleted',
    'bulk_state_update' => 'Bulk State Status Updated',
    'bulk_state_delete' => 'Bulk State Status Deleted',
    'gallery_for_product' => 'Gallery for Product',
    'apply' => 'Apply',
    'export' => 'Export',
    'close' => 'Close',
    'all_status' => 'All Status',
    'all' => 'All ',
    'upload_images' => 'Upload Images ',
    'upload' => 'Upload',
    'remove' => 'Remove',
    'name' => 'Name',
    'search' => 'Search',
    'placeholder_phone' => 'Enter a Phone Number',
    'unisex' => 'Unisex',
    'male' => 'Male',
    'female' => 'Female',
    'intersex' => 'Intersex',
    'payment' => 'Payment',
    'order_code' => 'Order Code',
    'items' => 'Items',
    'placed_on' => 'Placed On',
    'type' => 'Type',
    'customer' => 'Customer',
    'currency' => 'Currency',
    'commission' => 'Commission',
    'confirm' => 'Confirm',
    'password_msg' => 'This is a secure area of the application. Please confirm your password before continuing.',
    'change_password' => 'Change Password',
    'save_changes' => 'Save Changes',
    'assign_staff' => 'Assign Staff',
    'logo' => 'Logo',
    'mini_logo' => 'Mini Logo',
    'dark_logo' => 'Dark Logo',
    'dark-mini_logo' => 'Dark Mini Logo',
    'favicon' => 'favicon',
    'select_staff' => 'Select Staff',
    'payout_to' => 'Payout To',
    'submit_date_filter' => 'Submit Date Filter',
    'total_product_revenue' => 'Data Filter Wise Total Product Revenue',
    'total_new_sales' => 'Data Filter Wise Total New Sales',
    'total_new_customers' => 'Data Filter Wise Total New Customers',
    'total_paid_commission' => 'Data Filter Wise Total Paid Commission',
    'total_revenue' => 'Data Filter Wise Total Revenue',
    'total_appointment_count' => 'Data Filter Wise Total of Appointments Count',
    'data_not_available' => 'Data is not available in this Table',
    'coupon_view' => 'View Coupon',
    'data_not_found' => ' No data found',
    "processing" => "Processing...",
    "search" => "Search:",
    "lengthMenu" => "Show _MENU_ entries",
    "info" => "Showing _START_ to _END_ of _TOTAL_ entries",
    "infoEmpty" => "No entries to show",
    "infoFiltered" => "(filtered from _MAX_ total entries)",
    "loadingRecords" => "Loading...",
    "zeroRecords" => "No matching records found",
    "paginate" => [
        "first" => "First",
        "last" => "Last",
        "next" => "Next",
        "previous" => "Previous"
    ],
    'add_manager' => 'Add Manager',
    'personal_information' => 'Personal Information',
    'branch_setting' => 'Branch Setting',
    'mail_template'=> 'Email Templete',
    'notification_template'=>'Notification Template',
    'user_type' =>'user type',
    'notification_template_details'=>'template',
    'notification_template_updated' => 'Notification template updated successfully.',
    'notification_template_not_found' => 'Notification template not found.',
    'notification_template_created' => 'Notification template created successfully.',
    'to_field_required' => 'The "to" field is required.',
];
